class DownloadResults(object):
    """
    This class contains the results of the download call as well as methods for accessing \
    the results.

    :var success: a list of :class:`LocalNexradFile <nexradaws.resources.localnexradfile.LocalNexradFile>` \
    objects representing the successful downloads
    :vartype success: list
    :var failed: a list of any :class:`AwsNexradFile <nexradaws.resources.awsnexradfile.AwsNexradFile>` \
    objects that failed to download
    :vartype error: list
    :var success_count: The number of successful downloads
    :vartype success_count: int
    :var failed_count: The number of downloads that failed
    :vartype failed_count: int
    :var total: The total number of nexrad files that were attempted
    :vartype total: int
    """
    def __init__(self,localfiles,failedfiles):
        super(DownloadResults, self).__init__()
        self._successfiles = localfiles
        self._failedfiles = failedfiles

    @property
    def failed_count(self):
        return len(self._failedfiles)

    @property
    def success_count(self):
        return len(self._successfiles)

    @property
    def total(self):
        return self.success_count + self.failed_count

    @property
    def success(self):
        return self._successfiles

    @property
    def failed(self):
        return self._failedfiles

    def iter_success(self):
        """
        A generator function that allows you to iterate over successful downloads

        >>> for localnexradfile in downloads.iter_success():
        >>>      ...do something...
        """
        for nexradfile in self.success:
            yield nexradfile

    def iter_failed(self):
        """
        A generator function that allows you to iterate over failed downloads

        >>> for remotenexradfile in downloads.iter_failed():
        >>>      ...do something...
        """
        for awsnexradfile in self.failed:
            yield awsnexradfile





from distutils.core import setup

setup(
    name='nexradaws',
    version='1.0.1',
    packages=['nexradaws','nexradaws.resources'],
    description= 'Query and download NEXRAD data from AWS S3 storage.',
    long_description= '''This module is designed to allow you to query and download Nexrad
radar files from Amazon Web Services S3 Storage. The real-time feed and full historical archive of original
resolution (Level II) NEXRAD data, from June 1991 to present, is now freely available on Amazon S3 for anyone to use.
More information can be found here https://aws.amazon.com/public-datasets/nexrad/.

If pyart is installed nexradaws allows you to quickly get pyart objects of downloaded files.

nexradaws supports Python 2.7 and Python 3.6.

Github - https://github.com/aarande/nexradaws

PyPi - https://pypi.python.org/pypi/nexradaws

Docs - http://nexradaws.readthedocs.io/en/latest/

**Required dependencies**

* boto3
* pytz
* six

**Optional dependencies**

* pyart

**Install with pip**::

    pip install nexradaws''',
    url='https://github.com/aarande/nexradaws',
    license='MIT',
    author='Aaron Anderson',
    author_email='aaron.anderson74@yahoo.com',
    keywords='weather,radar,nexrad,aws,amazon',
    download_url='https://github.com/aarande/nexradaws/archive/1.0.tar.gz',
    install_requires=['boto3','pytz','six'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Atmospheric Science',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
    ],
)
